@@ -1,3 +1,4 @@
+from datetime import datetime
 from pathlib import Path
 from typing import Optional, Dict, List
 
@@ -29,7 +30,7 @@ def run_workflow(
     wf_description: str,
     ws_data: PhiWsData,
     target_env: WorkflowEnv,
-    target_dt: str,
+    target_dttm: datetime,
     dry_run: bool,
     detach: bool,
     target_app: Optional[str] = None,
@@ -39,7 +40,7 @@ def run_workflow(
     """Runs the Phidata Workflow in the target environment.
     The run_workflow() function is called from `phi wf run`
 
-    Step 1: Get the ws_root_path and products_dir
+    Step 1: Get the ws_root_path and workflows_dir
     Step 2: Get the workflow_file and workflow_name
     Step 3: Get the absolute workflow_file_path
     Step 4: Get DataProducts/Workflows/Tasks in the workflow_file_path
@@ -51,41 +52,41 @@ def run_workflow(
         return
     ws_config: WorkspaceConfig = ws_data.ws_config
 
-    # Step 1: Get the ws_root_path and products_dir
+    # Step 1: Get the ws_root_path and workflows_dir
     if ws_data.ws_root_path is None:
         logger.error("Workspace directory invalid")
         return
     ws_root_path: Path = ws_data.ws_root_path
 
-    if ws_config.products_dir is None:
-        logger.error("Products directory invalid")
+    if ws_config.workflows_dir is None:
+        logger.error("Workflow directory invalid")
         return
-    products_dir: str = ws_config.products_dir
+    workflows_dir: str = ws_config.workflows_dir
 
     # Step 2: Get the workflow_file and workflow_name
-    # The workflow_file is the path of the file relative to the products_dir.
+    # The workflow_file is the path of the file relative to the workflows_dir.
     print_subheading(f"Parsing: {wf_description}")
     workflow_file, workflow_name, task_name = parse_workflow_description(
         wf_description=wf_description,
         ws_root_path=ws_root_path,
-        products_dir=products_dir,
+        workflows_dir=workflows_dir,
     )
     # Validate workflow_file
     if workflow_file is None:
         logger.error("Workflow file not found")
         return
 
-    print_info("\tFile: {}".format(workflow_file))
+    print_info("File: {}".format(workflow_file))
     if workflow_name:
-        print_info("\tWorkflow: {}".format(workflow_name))
+        print_info("Workflow: {}".format(workflow_name))
     if task_name:
-        print_info("\tTask: {}".format(task_name))
+        print_info("Task: {}".format(task_name))
 
     # Step 3: Get the absolute workflow_file_path
     workflow_file_path: Path
     try:
         workflow_file_path = (
-            ws_root_path.joinpath(products_dir)
+            ws_root_path.joinpath(workflows_dir)
             .joinpath(workflow_file)
             .resolve(strict=True)
         )
@@ -119,7 +120,7 @@ def run_workflow(
     run_status: bool = False
     # Build the RunContext
     run_context = RunContext(
-        run_date=target_dt,
+        run_date=target_dttm,
         dry_run=dry_run,
         detach=detach,
         run_env=target_env.value,
@@ -176,19 +177,20 @@ def run_workflow(
             run_workflows_docker,
             run_data_products_docker,
         )
+        from phidata.utils.prep_infra_config import prep_infra_config
 
         # Find the DockerConfig to use
         docker_configs: Optional[List[DockerConfig]] = ws_config.docker
-        docker_config_to_use: Optional[DockerConfig] = None
+        filtered_docker_config: Optional[DockerConfig] = None
         if docker_configs is not None and isinstance(docker_configs, list):
             if len(docker_configs) == 1:
-                docker_config_to_use = docker_configs[0]
+                filtered_docker_config = docker_configs[0]
             else:
                 for dc in docker_configs:
-                    if dc.env == target_env:
-                        docker_config_to_use = dc
+                    if dc.env == target_env.value:
+                        filtered_docker_config = dc
                         break
-        if docker_config_to_use is None:
+        if filtered_docker_config is None:
             logger.error(f"No DockerConfig found for env: {target_env.value}")
             return
 
@@ -201,16 +203,17 @@ def run_workflow(
         #       when running the docker command
         ######################################################################
 
-        # The ws_root_path is the ROOT directory for the workspace
-        docker_config_to_use.workspace_root_path = ws_data.ws_root_path
-        docker_config_to_use.workspace_config_file_path = ws_data.ws_config_file_path
-        docker_config_to_use.scripts_dir = ws_config.scripts_dir
-        docker_config_to_use.storage_dir = ws_config.storage_dir
-        docker_config_to_use.meta_dir = ws_config.meta_dir
-        docker_config_to_use.products_dir = ws_config.products_dir
-        docker_config_to_use.notebooks_dir = ws_config.notebooks_dir
-        docker_config_to_use.workspace_config_dir = ws_config.workspace_config_dir
-        docker_config_to_use.docker_env = ws_config.docker_env
+        docker_config_to_use: Optional[DockerConfig] = None
+        _config = prep_infra_config(
+            infra_config=filtered_docker_config,
+            ws_config=ws_config,
+        )
+        if isinstance(_config, DockerConfig):
+            docker_config_to_use = _config
+
+        if docker_config_to_use is None:
+            logger.error(f"No DockerConfig found for env: {target_env.value}")
+            return
 
         # ** CASE 1: If a workflow_name or a task_name is provided
         if (workflow_name is not None and len(wf_dict) > 0) or (
@@ -313,18 +316,19 @@ def run_workflow(
             run_workflows_k8s,
             run_data_products_k8s,
         )
+        from phidata.utils.prep_infra_config import prep_infra_config
 
         k8s_configs: Optional[List[K8sConfig]] = ws_config.k8s
-        k8s_config_to_use: Optional[K8sConfig] = None
+        filtered_k8s_config: Optional[K8sConfig] = None
         if k8s_configs is not None and isinstance(k8s_configs, list):
             if len(k8s_configs) == 1:
-                k8s_config_to_use = k8s_configs[0]
+                filtered_k8s_config = k8s_configs[0]
             else:
-                for dc in k8s_configs:
-                    if dc.env == target_env:
-                        k8s_config_to_use = dc
+                for kc in k8s_configs:
+                    if kc.env == target_env.value:
+                        filtered_k8s_config = kc
                         break
-        if k8s_config_to_use is None:
+        if filtered_k8s_config is None:
             logger.error(f"No K8sConfig found for env: {target_env.value}")
             return
 
@@ -337,16 +341,17 @@ def run_workflow(
         #       when running the k8s command
         ######################################################################
 
-        # The ws_root_path is the ROOT directory for the workspace
-        k8s_config_to_use.workspace_root_path = ws_data.ws_root_path
-        k8s_config_to_use.workspace_config_file_path = ws_data.ws_config_file_path
-        k8s_config_to_use.scripts_dir = ws_config.scripts_dir
-        k8s_config_to_use.storage_dir = ws_config.storage_dir
-        k8s_config_to_use.meta_dir = ws_config.meta_dir
-        k8s_config_to_use.products_dir = ws_config.products_dir
-        k8s_config_to_use.notebooks_dir = ws_config.notebooks_dir
-        k8s_config_to_use.workspace_config_dir = ws_config.workspace_config_dir
-        k8s_config_to_use.k8s_env = ws_config.k8s_env
+        k8s_config_to_use: Optional[K8sConfig] = None
+        _config = prep_infra_config(
+            infra_config=filtered_k8s_config,
+            ws_config=ws_config,
+        )
+        if isinstance(_config, K8sConfig):
+            k8s_config_to_use = _config
+
+        if k8s_config_to_use is None:
+            logger.error(f"No K8sConfig found for env: {target_env.value}")
+            return
 
         # ** CASE 1: If a workflow_name is provided
         #   Run only the Workflow
@@ -469,24 +474,24 @@ def list_workflows(
         return
     ws_config: WorkspaceConfig = ws_data.ws_config
 
-    # Step 1: Get the ws_root_path and products_dir
+    # Step 1: Get the ws_root_path and workflows_dir
     if ws_data.ws_root_path is None:
         logger.error("Workspace directory invalid")
         return
     ws_root_path: Path = ws_data.ws_root_path
 
-    if ws_config.products_dir is None:
-        logger.error("Products directory invalid")
+    if ws_config.workflows_dir is None:
+        logger.error("Workflow directory invalid")
         return
-    products_dir: str = ws_config.products_dir
+    workflows_dir: str = ws_config.workflows_dir
 
     # Step 2: Get the workflow_file and workflow_name
-    # The workflow_file is the path of the file relative to the products_dir.
+    # The workflow_file is the path of the file relative to the workflows_dir.
     print_subheading(f"Parsing: {wf_description}")
     workflow_file, workflow_name, task_name = parse_workflow_description(
         wf_description=wf_description,
         ws_root_path=ws_root_path,
-        products_dir=products_dir,
+        workflows_dir=workflows_dir,
     )
     # Validate workflow_file
     if workflow_file is None:
@@ -503,7 +508,7 @@ def list_workflows(
     workflow_file_path: Path
     try:
         workflow_file_path = (
-            ws_root_path.joinpath(products_dir)
+            ws_root_path.joinpath(workflows_dir)
             .joinpath(workflow_file)
             .resolve(strict=True)
         )
