@@ -10,8 +10,8 @@ from phidata.infra.docker.config import DockerConfig
 from phidata.infra.k8s.config import K8sConfig
 from phidata.infra.aws.config import AwsConfig
 from phidata.workspace import WorkspaceConfig
+from phidata.utils.prep_infra_config import prep_infra_config
 
-from phiterm.backend_api.workspace_api import update_workspace, upsert_workspace
 from phiterm.conf.constants import DEFAULT_WS_NAME
 from phiterm.conf.phi_conf import PhiConf, PhiWsData
 from phiterm.enums.user_enums import VersionControlProviderEnum
@@ -87,7 +87,7 @@ def create_new_workspace(ws_name: str, template: WorkspaceStarterTemplate) -> bo
             f"\nNote: If you would like to setup the workspace instead, run `phi ws setup` from the workspace directory"
         )
         delete_existing_ws_data = typer.confirm(
-            f"Would you like to delete existing workspace data and create a new workspace?",
+            f"Would you like to delete existing record from phidata and create a new record?",
             default=True,
         )
         if delete_existing_ws_data:
@@ -99,7 +99,7 @@ def create_new_workspace(ws_name: str, template: WorkspaceStarterTemplate) -> bo
     ws_root_path: Path = current_dir.joinpath(ws_name)
     if ws_root_path.exists():
         logger.error(
-            f"Directory {ws_root_path} exists, please delete manually or choose another name for workspace"
+            f"Directory {ws_root_path} exists, please delete files manually or choose another name for workspace"
         )
         return False
 
@@ -301,7 +301,7 @@ def initialize_workspace() -> None:
     #         return
     #     return
     # else:
-    print_heading("Creating a new workspace")
+    print_heading("New phidata workspace")
     create_workspace_using_input()
 
 
@@ -511,14 +511,12 @@ def setup_workspace(ws_root_path: Path) -> bool:
         scripts_dir = ws_data.ws_config.scripts_dir
         install_deps_file = f"sh {ws_root_path}/{scripts_dir}/install.sh"
         print_subheading(f"Setup complete! Next steps:\n")
-        print_info("1. Update your workspace config:")
-        print_info(f"\t{str(_ws_config_file_path)}")
-        print_info("2. Install your workspace:")
-        print_info(f"\t{install_deps_file}")
-        print_info("3. Dry-run workspace deploy:")
-        print_info("\tphi ws up -dr")
-        print_info("4. Deploy your workspace:")
+        print_info("1. Deploy workspace:")
         print_info("\tphi ws up")
+        print_info("2. Update workspace config:")
+        print_info(f"\t{str(_ws_config_file_path)}")
+        print_info("3. Install workspace dependencies:")
+        print_info(f"\t{install_deps_file}")
         # if pending_actions and len(pending_actions) > 0:
         #     print_info("3. Complete pending actions:")
         #     print_howtofix_pending_actions(pending_actions)
@@ -534,14 +532,12 @@ def setup_workspace(ws_root_path: Path) -> bool:
 
 
 def filter_and_prep_configs(
-    ws_data: PhiWsData,
-    target_env: Optional[WorkspaceEnv] = None,
+    ws_config: WorkspaceConfig,
+    target_env: Optional[str] = None,
     target_config: Optional[WorkspaceConfigType] = None,
     order: Literal["create", "delete"] = "create",
 ) -> List[InfraConfig]:
 
-    ws_config: WorkspaceConfig = ws_data.ws_config
-
     # Step 1. Filter configs
     # 1.1: Filter by config type: docker/k8s/aws
     filtered_configs: List[InfraConfig] = []
@@ -576,22 +572,18 @@ def filter_and_prep_configs(
 
     # 1.2: Filter by env: dev/stg/prd
     configs_after_env_filter: List[InfraConfig] = []
-    if target_env is None or target_env == WorkspaceEnv.all:
+    if target_env is None or target_env == "all":
         configs_after_env_filter = filtered_configs
     else:
         for config in filtered_configs:
             if config.env is None:
                 continue
-            if config.env.lower() not in WorkspaceEnv.values_list():
-                logger.error(f"{config.env} not supported")
-                continue
-            config_env = WorkspaceEnv.from_str(config.env)
-
-            if config_env == target_env:
+            if target_env == config.env:
                 configs_after_env_filter.append(config)
     # logger.debug("Filtered configs: {}".format(configs_after_env_filter))
 
     # Step 2. Prepare configs
+    ready_to_use_configs: List[InfraConfig] = []
     for config in configs_after_env_filter:
         if not isinstance(config, InfraConfig):
             logger.error(f"{config} is not an instance of InfraConfig")
@@ -607,56 +599,21 @@ def filter_and_prep_configs(
 
         ######################################################################
         # NOTE: VERY IMPORTANT TO GET RIGHT
-        # Update subconfigs using the WorkspaceConfig
-        # 1. Pass down the paths from the WorkspaceConfig
-        #       These paths are used everywhere from Infra, Apps, Resources, Workflows
-        # 2. Pass down local_env, docker_env, k8s_env for building PhidataApps
-        # 3. Pass down common cloud configuration. eg: aws_region, aws_profile
         ######################################################################
 
-        # -*- Path parameters
-        # The ws_root_path is the ROOT directory for the workspace
-        config.workspace_root_path = ws_data.ws_root_path
-        config.workspace_config_file_path = ws_data.ws_config_file_path
-        config.scripts_dir = ws_config.scripts_dir
-        config.storage_dir = ws_config.storage_dir
-        config.meta_dir = ws_config.meta_dir
-        config.products_dir = ws_config.products_dir
-        config.notebooks_dir = ws_config.notebooks_dir
-        config.workspace_config_dir = ws_config.workspace_config_dir
-
-        # -*- Environment parameters
-        # only update the param if they are not available.
-        # prefer the configs param if provided
-        if config.local_env is None and ws_config.local_env is not None:
-            config.local_env = ws_config.local_env
-        if config.docker_env is None and ws_config.docker_env is not None:
-            config.docker_env = ws_config.docker_env
-        if config.k8s_env is None and ws_config.k8s_env is not None:
-            config.k8s_env = ws_config.k8s_env
-
-        # -*- AWS parameters
-        # only update the param if they are available.
-        # prefer the configs param if provided
-        if config.aws_region is None and ws_config.aws_region is not None:
-            config.aws_region = ws_config.aws_region
-        if config.aws_profile is None and ws_config.aws_profile is not None:
-            config.aws_profile = ws_config.aws_profile
-        if config.aws_config_file is None and ws_config.aws_config_file is not None:
-            config.aws_config_file = ws_config.aws_config_file
-        if (
-            config.aws_shared_credentials_file is None
-            and ws_config.aws_shared_credentials_file is not None
-        ):
-            config.aws_shared_credentials_file = ws_config.aws_shared_credentials_file
+        _config = prep_infra_config(
+            infra_config=config,
+            ws_config=ws_config,
+        )
+        ready_to_use_configs.append(_config)
 
     # Return filtered and prepared configs
-    return configs_after_env_filter
+    return ready_to_use_configs
 
 
 def deploy_workspace(
     ws_data: PhiWsData,
-    target_env: Optional[WorkspaceEnv] = None,
+    target_env: Optional[str] = None,
     target_config: Optional[WorkspaceConfigType] = None,
     target_name: Optional[str] = None,
     target_type: Optional[str] = None,
@@ -670,8 +627,12 @@ def deploy_workspace(
         logger.error("WorkspaceConfig invalid")
         return
 
+    ws_config: WorkspaceConfig = ws_data.ws_config
+    # Set the local environment variables before processing configs
+    ws_config.set_local_env()
+
     configs_to_deploy: List[InfraConfig] = filter_and_prep_configs(
-        ws_data=ws_data,
+        ws_config=ws_config,
         target_env=target_env,
         target_config=target_config,
         order="create",
@@ -730,7 +691,7 @@ def deploy_workspace(
 
 def shutdown_workspace(
     ws_data: PhiWsData,
-    target_env: Optional[WorkspaceEnv] = None,
+    target_env: Optional[str] = None,
     target_config: Optional[WorkspaceConfigType] = None,
     target_name: Optional[str] = None,
     target_type: Optional[str] = None,
@@ -744,8 +705,12 @@ def shutdown_workspace(
         logger.error("WorkspaceConfig invalid")
         return
 
+    ws_config: WorkspaceConfig = ws_data.ws_config
+    # Set the local environment variables before processing configs
+    ws_config.set_local_env()
+
     configs_to_shutdown: List[InfraConfig] = filter_and_prep_configs(
-        ws_data=ws_data,
+        ws_config=ws_config,
         target_env=target_env,
         target_config=target_config,
         order="delete",
@@ -806,7 +771,7 @@ def shutdown_workspace(
 
 def patch_workspace(
     ws_data: PhiWsData,
-    target_env: Optional[WorkspaceEnv] = None,
+    target_env: Optional[str] = None,
     target_config: Optional[WorkspaceConfigType] = None,
     target_name: Optional[str] = None,
     target_type: Optional[str] = None,
@@ -820,8 +785,12 @@ def patch_workspace(
         logger.error("WorkspaceConfig invalid")
         return
 
+    ws_config: WorkspaceConfig = ws_data.ws_config
+    # Set the local environment variables before processing configs
+    ws_config.set_local_env()
+
     configs_to_patch: List[InfraConfig] = filter_and_prep_configs(
-        ws_data=ws_data,
+        ws_config=ws_config,
         target_env=target_env,
         target_config=target_config,
         order="create",
